%% Discretization
% This file generates plots clarifying the zero-order hold and 
% first-order hold assumptions for controller discretization.

%% Measurement signals

% Sampled Discrete-time
delt = 0.1;         % Sample Time Interval, sec
td = [0.2 0.3];     % Sample Times, sec
Nd = numel(td);
ed = 1+td-sin(12*td+1.2);

% Continuous-time
Nc = 40;
tc = sort([td linspace(0,0.35,Nc)]);
ec = 1+tc-sin(12*tc+1.2);


%% Continuous time Error
figure(1); clf;
plot(tc,ec,'b'); 
hold on;
ph = [];
for k=1:Nd;
    ph(k) = plot( [td(k) td(k)], [0 ed(k)],'r:');
end

% Patch for integral area
idx = find( tc>= td(1) & tc<=td(2) );
tI = [tc(idx) tc(idx(end)) tc(idx(1)) tc(idx(1))];
eI = [ec(idx) 0 0 ec(idx(1))];
patch(tI,eI,'b','FaceAlpha',0.2,'LineStyle','none')

xl=xlabel('Time, t');
yl=ylabel('Error, e(t)');
xlim([0 tc(end)]);
grid on;
set(gca, 'LooseInset', get(gca, 'TightInset'));
set(gca,'Xtick',td,'XTickLabel',{'(k-1) \Delta t','k \Delta t'});

if exist('garyfyFigure','file') && exist('myprint','file')
    % Code to clean up and save figure.
    % These functions are not in the standard Matlab release.
    garyfyFigure
    set([xl yl],'FontSize',18)
    myprint(1,'EContTime')
end

%% Discrete time error with zero-order hold

figure(2); clf;
ph = plot(tc,ec,'b:');
hold on;
plot(td,[ed(1) ed(1)],'r:');
for k=1:Nd;
    plot( [td(k) td(k)], [0 ed(k)],'r');
    plot( td(k), ed(k), 'r.','MarkerSize',24);
end
th(1)=text(td(1)-0.03,ed(1)+0.17,'e_{k-1}');
th(2)=text(td(2)+0.005,ed(2)+0.125,'e_k');
hold off;

% Patch for integral area
tI = [td(1) td(2) td(2) td(1) td(1)];
eI = [ed(1) ed(1) 0 0 ed(1)];
patch(tI,eI,'r','FaceAlpha',0.2,'LineStyle','none')

xl=xlabel('Time, t');
yl=ylabel('Error, e(t)');
set(gca,'Xtick',td,'XTickLabel',{'(k-1) \Delta t','k \Delta t'});
xlim([0 tc(end)]);
grid on;
set(gca, 'LooseInset', get(gca, 'TightInset'));

if exist('garyfyFigure','file') && exist('myprint','file')
    % Code to clean up and save figure.
    % These functions are not in the standard Matlab release.
    garyfyFigure
    set([th xl yl],'FontSize',18)
    myprint(2,'EZOH')
end


%% Discrete time error with first-order hold

figure(3); clf;
ph = plot(tc,ec,'b:');
hold on;
plot(td,ed,'r:');
for k=1:Nd;
    plot( [td(k) td(k)], [0 ed(k)],'r');
    plot( td(k), ed(k), 'r.','MarkerSize',24);
end
th(1)=text(td(1)-0.03,ed(1)+0.17,'e_{k-1}');
th(2)=text(td(2)+0.005,ed(2)+0.125,'e_k');
hold off;

% Patch for integral area
tI = [td(1) td(2) td(2) td(1) td(1)];
eI = [ed(1) ed(2) 0 0 ed(1)];
ph = patch(tI,eI,'r','FaceAlpha',0.2,'LineStyle','none');

xl=xlabel('Time, t');
yl=ylabel('Error, e(t)');
set(gca,'Xtick',td,'XTickLabel',{'(k-1) \Delta t','k \Delta t'});
%ylabel('Error, e_k');
%set(gca,'Xtick',td,'XTickLabel',{'k-1','k'});
xlim([0 tc(end)]);
grid on;
set(gca, 'LooseInset', get(gca, 'TightInset'));

if exist('garyfyFigure','file') && exist('myprint','file')
    % Code to clean up and save figure.
    % These functions are not in the standard Matlab release.
    garyfyFigure
    set([th xl yl],'FontSize',18)
    myprint(3,'EFOH')    
end
